#!/bin/bash
###############################################################################
# SSS-1514 patch: cleanup nullmailer/queue & install fix
#                 for 5.9.6 - 5.9.8 (although MAX_VERSION not checked)
###############################################################################

PATCH_TITLE="Cleanup & prevent cron mail files"
MIN_VERSION="5.9.6"

MOTD=/etc/motd
PATCH_CONFIG=/etc/patch.conf
SW_VERSION=$(grep -o "[0-9]*[.][0-9]*[.][0-9]*" "${MOTD}")
SYSTEM_MODEL_PATH=/srv/www2/app/Model/System.php

host_name="$(/bin/hostname)"
log_format="$(/bin/date +"%b %d %T") ${host_name} ${host_name}: [patch]"
UPDATE_LOG=/home/spectracom/log/update.log
applied=1  # Use a return code, so 0 mean 'true'

target_files=(
	'/var/spool/fcron/root.orig'
)

trap '/bin/sync' EXIT

version_greater_or_equal() {
	local current=$1
	local target=$2

	IFS=. read -r cmajor cminor cpatch <<<"${current}"
	IFS=. read -r tmajor tminor tpatch <<<"${target}"

	if [[ cmajor -gt tmajor ]]; then
		return 0
	elif [[ cmajor -lt tmajor ]]; then
		return 1
	fi

	if [[ cminor -gt tminor ]]; then
		return 0
	elif [[ cminor -lt tminor ]]; then
		return 1
	fi

	if [[ cpatch -gt tpatch ]]; then
		return 0
	elif [[ cpatch -lt tpatch ]]; then
		return 1
	fi

	return 0
}

echo "${log_format} installing ${PATCH_TITLE}" >> ${UPDATE_LOG}

if ! version_greater_or_equal "${SW_VERSION}" "${MIN_VERSION}"; then
	echo "${log_format} version not supported or not found" >> ${UPDATE_LOG}
	exit 1 # A minimum or newer version was not found
fi


if rm /var/spool/nullmailer/queue/*; then
	echo "${log_format} queue files removed" >> ${UPDATE_LOG}
fi

for i in "${target_files[@]}"; do
	[ -f "${i}" ] || continue

	read LINEREAD < "${i}"
	[ -z "${LINEREAD##*!mail(false)*}" ] && continue

	sed -i '1 i !mail(false)' "${i}"
	applied=0
done

if [ "${applied}" -ne 0 ]; then
	echo "${log_format} nothing to do, patch not applied" >> ${UPDATE_LOG}
	exit 0
fi


# Update /etc/hotpatch.conf to reflect addition of this patch
echo "${SW_VERSION} ${PATCH_TITLE}" >> ${PATCH_CONFIG}

# Change system.php to target hotpatch.conf files in /etc/, so that it is not preserved by filelist.txt
# shellcheck disable=SC1117
sed -i "s!\(const HOTPATCH_CONFIG\) = '/home/spectracom/config/hotpatch.conf'!\1 = '/etc/patch.conf'!" ${SYSTEM_MODEL_PATH}

sudo reboot
